@@ -5,21 +5,21 @@ main app base class with context help for flow and app state changes
 the class :class:`HelpAppBase` provided by this namespace portion is extending your application with a context-sensitive
 help functionality.
 
-the data-driven approach allows to add, edit and remove help texts without the need to change a single line of code or
-to recompile your app. this gets achieved within :class:`HelpAppBase` by overriding the main app class methods
+the data-driven approach allows ad-hoc-changes of your app's help texts without the need of code changes or
+recompilation. this gets achieved within :class:`HelpAppBase` by overriding the main app class methods
 :meth:`~ae.gui_app.MainAppBase.change_flow` and :meth:`~ae.gui_app.MainAppBase.change_app_state`.
 
 so to add help support to the widgets of your app you only need to add/provide the help texts with a help id that is
 matching the value of the :attr:`help_id` attribute of the widget you need help for.
 
-additionally you can provide a separate i18n translation message file for each of the supported languages to make your
-help texts multi-lingual.
+additionally, you can provide a separate i18n translation message file for each of the supported languages to make your
+help texts multilingual.
 
 
 help layout implementation example
 ----------------------------------
 
-:class:`HelpAppBase` inherits from :class:`~ae.gui_app.MainAppBase` while still being independent from the used GUI
+:class:`HelpAppBase` inherits from :class:`~ae.gui_app.MainAppBase` while still being independent of the used GUI
 framework/library.
 
 .. note::
@@ -66,7 +66,7 @@ additional helper functions
 ---------------------------
 
 the helper functions :func:`anchor_layout_x`, :func:`anchor_layout_y`, :func:`anchor_points` and :func:`anchor_spec` are
-calculating framework-independent the position and direction of the a targeting tooltip anchor arrow and its layout box.
+calculating framework-independent the position and direction of the targeting tooltip anchor arrow and its layout box.
 
 
 flow change context message id
@@ -85,7 +85,7 @@ if there is no need for a detailed message id that is taking the flow key into a
 message id without the flow key.
 
 the method :meth:`~HelpAppBase.help_display` does first search for a message id including the flow key in the available
-help text files and if not found it will automatically fallback to use a message id without the flow key::
+help text files and if not found it will automatically fall back to use a message id without the flow key::
 
     'help_flow#open_item'
 
@@ -105,7 +105,7 @@ the message ids for app state change help texts are using the prefix marker stri
 pluralize-able help texts
 -------------------------
 
-each message id can optionally have several different help texts for their pluralization. for that simply add a `count`
+each message id can optionally have several help texts for their pluralization. for that simply add a `count`
 item to the `help_vars` property of the help target widget and then define a help text for the all the possible count
 cases in your message text file like shown in the following example::
 
@@ -163,15 +163,13 @@ current system/environment.
 the declaration and association of message ids and their related help messages is done with the help of the namespace
 portion :mod:`ae.i18n`.
 
+.. hint::
+    more details on these and other features of this help system, e.g. the usage of f-strings in the help texts, is
+    documented in the doc string of the :mod:`ae.i18n` module.
 
-further examples
-----------------
+    a more complex example app demonstrating the features of this context help system can be found in the repository of
+    the `kivy lisz demo app <https://gitlab.com/ae-group/kivy_lisz>`_.
 
-more details on these and other features of this help system, e.g. the usage of f-strings in the help texts, is
-documented in the doc string of the :mod:`ae.i18n` module.
-
-a more complex example app demonstrating the features of this context help system can be found in the repository of the
-`kivy lisz demo app <https://gitlab.com/ae-group/kivy_lisz>`_.
 
 app tours
 =========
@@ -190,9 +188,9 @@ app tour start and stop events
 the following main app event methods get called (if they exist) in relation to the start/stop of an app tour:
 
 * `on_tour_init`: fired when the app tour instance got initialized and the app states backup got saved.
-* `on_tour_start`: fired after tour start() method get called (delay id configurable via `tour_start_delay` page data).
+* `on_tour_start`: fired after tour start() method get called; delay id configurable via `tour_start_delay` page data.
 * `on_tour_exit`: fired after an app tour got finished and the app states got restored to the values of the tour start.
-  fired delayed to let UI events get processed; delay seconds configurable via the `tour_exit_delay` page data value).
+  fired delayed letting UI events get processed; delay seconds configurable via the `tour_exit_delay` page data value.
 
 
 UI-specific implementation
@@ -203,7 +201,7 @@ highlighting the widget explained and to display a tooltip and the tour page tex
 
 .. hint:: the :class:`~ae.kivy_help.TourOverlay` class is a quite complete implementation of a tour layout class.
 
-optionally for the 'user_registration' page of the :class:`OnboardingTour` a open user name editor flow has to be
+optionally for the 'user_registration' page of the :class:`OnboardingTour` an open username editor flow has to be
 implemented.
 """
 from abc import abstractmethod, ABC
@@ -216,7 +214,7 @@ from ae.gui_app import (
     FLOW_KEY_SEP, flow_action, flow_class_name, flow_path_id, id_of_flow, update_tap_kwargs, MainAppBase)
 
 
-__version__ = '0.3.43'
+__version__ = '0.3.44'
 
 
 register_package_translations()
@@ -312,10 +310,10 @@ def anchor_spec(wid_x: float, wid_y: float, wid_width: float, wid_height: float,
                             * anchor_dir (anchor direction: 'r'=right, 'i'=increase-y, 'l'=left, 'd'=decrease-y)
 
                             .. note::
-                                the direction in the y axis got named increase for higher y values and `decrease` for
+                                the direction in the y-axis got named increase for higher y values and `decrease` for
                                 lower y values to support different coordinate systems of the GUI frameworks.
 
-                                e.g. Kivy has the y axis zero value at the bottom of the app window, whereas in enaml/Qt
+                                e.g. Kivy has the y-axis zero value at the bottom of the app window, whereas in enaml/Qt
                                 it is at the top.
 
     """
@@ -456,12 +454,12 @@ def widget_page_id(wid: Optional[Any]) -> str:
 
 
 class TourBase:
-    """ abstract tour base class, automatically registering sub-classes as app tours.
+    """ abstract tour base class, automatically registering subclasses as app tours.
 
-    sub-class this generic, UI-framework-independent base class to bundle pages of a tour and make sure that the
-    attr:`~TourBase.page_ids` and :attr:`~TourBase.page_data` attributes are correctly set. an UI-framework-dependent
+    subclass this generic, UI-framework-independent base class to bundle pages of a tour and make sure that the
+    attr:`~TourBase.page_ids` and :attr:`~TourBase.page_data` attributes are correctly set. a UI-framework-dependent
     tour overlay/layout instance, created and assigned to main_app.tour_layout, will automatically create an instance
-    of your tour-specific sub-class on tour start.
+    of your tour-specific subclass on tour start.
     """
     def __init_subclass__(cls, **kwargs):
         """ register tour class; called on declaration of tour subclass. """
@@ -541,7 +539,7 @@ class TourBase:
 
         self.backup_app_states()
 
-        main_app.call_method('on_tour_init', self)  # notify main app to backup additional app-specific non-app-states
+        main_app.call_method('on_tour_init', self)  # notify main app to back up additional app-specific non-app-states
 
     def backup_app_states(self):
         """ backup current states of this app, including flow. """
@@ -765,7 +763,7 @@ class TourBase:
         """ stop/cancel tour. """
         self.main_app.vpo("TourBase.stop")
         self.teardown_app_flow()
-        # notify main app to restore additional app-specific states (delayed to be called after teardown events)
+        # notify main app to restore additional app-specific states (delayed, to be called after teardown events)
         self.main_app.call_method_delayed(self.page_data.get('tour_exit_delay', TOUR_EXIT_DELAY_DEF),
                                           'on_tour_exit', self)
 
@@ -848,7 +846,7 @@ class OnboardingTour(TourBase):
 
         if started > main_app.get_var('onboarding_tour_max_started', default_value=9):
             # this would remove welcome and base pages, unreachable for the user:  ids[:] = ids[ids.index('tour_end'):]
-            self.page_idx = self.page_ids.index('tour_end')   # .. instead jump to last page before user registration
+            self.page_idx = self.page_ids.index('tour_end')   # .. instead, jump to last page before user registration
 
     def setup_app_flow(self):
         """ overridden to open user preferences dropdown in responsible_layout tour page. """
@@ -897,7 +895,7 @@ class HelpAppBase(MainAppBase, ABC):
     help_activator: Any = None                  #: help mode de-/activator button widget
     help_layout: Optional[Any] = None           #: help text container widget in active help mode else None
     tour_layout: Optional[Any] = None           #: tour layout/overlay widget in active tour mode else None
-    tour_overlay_class: Optional[Type] = None   #: UI-framework-specific tour overlay class, set by main app sub-class
+    tour_overlay_class: Optional[Type] = None   #: UI-framework-specific tour overlay class, set by main app subclass
 
     _next_help_id: str = ''                     #: last app-state/flow change to show help text on help mode activation
     _closing_popup_open_flow_id: str = ''       #: flow id of just closed popup
@@ -984,7 +982,7 @@ class HelpAppBase(MainAppBase, ABC):
 
         ret = self.help_display(help_id, help_vars, key_suffix='after' if changed else '')
         if help_id == self.displayed_help_id and not changed:
-            ret = False             # allow to execute app state change
+            ret = False             # allow app state change
         return ret
 
     def help_display(self, help_id: str, help_vars: Dict[str, Any], key_suffix: str = '', must_have: bool = False
@@ -1054,7 +1052,7 @@ class HelpAppBase(MainAppBase, ABC):
         ret = self.help_display(help_id, help_vars, key_suffix=key_suffix, must_have=not changed)
         self._closing_popup_open_flow_id = ''
         if not changed and (help_id == self.displayed_help_id or flow_action(flow_id) == 'open'):
-            # allow to execute flow change of currently explained flow button or if open flow action with no help text
+            # allow flow change of currently explained flow button or if open flow action with no help text
             ret = False
         return ret
 
@@ -1182,7 +1180,7 @@ class HelpAppBase(MainAppBase, ABC):
         return self.widget_by_flow_id(page_id) or self.widget_by_app_state_name(page_id)
 
     def widget_tourable_children_page_ids(self, parent_widget: Any) -> List:
-        """" determine all visible and tourable children widgets of the passed parent and its child container widgets.
+        """ determine all visible and tourable children widgets of the passed parent and its child container widgets.
 
         :param parent_widget:   parent widget to determine all children that are tourable.
         :return:                list of page ids of tourable children of the passed parent widget.
